# Features


## Releases
- [X] Aircrack-ng 1.6 support
- [X] Aircrack-ng 1.7 support

## Supported tools
- [X] [Airbase-Ng](https://www.aircrack-ng.org/doku.php?id=airbase-ng)
- [X] [Airdecap-Ng](https://www.aircrack-ng.org/doku.php?id=airdecap-ng)
- [X] [Aircrack-Ng](https://www.aircrack-ng.org/doku.php?id=aircrack-ng)
    * [X] Custom data models
    * [X] Shortcuts for cracking specific APs
- [X] [Airdecloack-Ng](https://www.aircrack-ng.org/doku.php?id=airdecloak-ng)
- [X] [Aireplay-Ng](https://www.aircrack-ng.org/doku.php?id=aireplay-ng)
- [X] [Airmon-Ng](https://www.aircrack-ng.org/doku.php?id=airmon-ng)
- [X] [Airodump-Ng](https://www.aircrack-ng.org/doku.php?id=airodump-ng)
    * [X] Custom data models
    * [X] ".airodump" properties on models
- [ ] airdecloak-ng
- [ ] airdrop-ng
- [ ] airgraph-ng
- [ ] airolib-ng
- [ ] airserv-ng
- [ ] airtun-ng
- [ ] besside-ng
- [ ] easside-ng
- [ ] wesside-ng
- [ ] dcrack
- [ ] packetforge-ng

